@@ -25,17 +25,45 @@
 #include <filesystem>
 #include <string>
 #include <vector>
+#include "easyeffects_db_convolver.h"
 #include "pipeline_type.hpp"
 
 class ConvolverKernelManager {
  public:
   struct KernelData {
+    bool is_sofa = false;
+
     uint rate = 0;
-    std::vector<float> left_channel;
-    std::vector<float> right_channel;
+    uint original_rate = 0;
+    uint channels = 0;
+
     QString name;
     QString file_path;
 
+    std::vector<float> channel_L;
+    std::vector<float> channel_LR;
+    std::vector<float> channel_RL;
+    std::vector<float> channel_R;
+
+    struct SofaMetadata {
+      QString database;
+
+      int index = 0;  // Which measurement to use
+      int measurements = 1;
+
+      float azimuth = 0.0;    // In degrees
+      float elevation = 0.0;  // In degrees
+      float radius = 0.0;     // In meters
+
+      float min_azimuth = 0.0F;
+      float max_azimuth = 0.0F;
+      float min_elevation = 0.0F;
+      float max_elevation = 0.0F;
+      float min_radius = 0.0F;
+      float max_radius = 0.0F;
+
+    } sofaMetadata;
+
     [[nodiscard]] auto isValid() const -> bool;
 
     [[nodiscard]] auto duration() const -> double;
@@ -43,7 +71,7 @@ class ConvolverKernelManager {
     [[nodiscard]] auto sampleCount() const -> size_t;
   };
 
-  ConvolverKernelManager(const PipelineType& pipeline_type);
+  ConvolverKernelManager(db::Convolver* settings, const PipelineType& pipeline_type);
 
   auto loadKernel(const std::string& name) -> KernelData;
 
@@ -58,8 +86,13 @@ class ConvolverKernelManager {
 
   auto saveKernel(const KernelData& kernel, const std::string& file_name) -> bool;
 
+  auto readSofaKernelFile(const std::string& file_path) -> KernelData;
+
  private:
+  db::Convolver* settings = nullptr;
+
   static constexpr std::string irs_ext = ".irs";
+  static constexpr std::string sofa_ext = ".sofa";
 
   PipelineType pipeline_type;
 
@@ -76,4 +109,6 @@ class ConvolverKernelManager {
       -> std::string;
 
   static auto directConvolution(const std::vector<float>& a, const std::vector<float>& b) -> std::vector<float>;
+
+  static auto getFileExtension(const std::string& file_path) -> std::string;
 };
\ No newline at end of file
