@@ -46,6 +46,10 @@ FirFilterBase::FirFilterBase(std::string tag) : log_tag(std::move(tag)) {}
 FirFilterBase::~FirFilterBase() {
   zita_ready = false;
 
+  free_zita();
+}
+
+void FirFilterBase::free_zita() {
   if (conv != nullptr) {
     conv->stop_process();
 
@@ -148,23 +152,15 @@ void FirFilterBase::setup_zita() {
     return;
   }
 
-  if (conv != nullptr) {
-    conv->stop_process();
-
-    while (!conv->check_stop()) {
-      std::this_thread::sleep_for(std::chrono::milliseconds(1));
-    }
-
-    delete conv;
-
-    conv = nullptr;
-  }
+  free_zita();
 
   conv = new Convproc();
 
   conv->set_options(0);
 
-  int ret = conv->configure(2, 2, kernel.size(), n_samples, n_samples, n_samples, 0.0F /* density */);
+  float density = 0.5F;
+
+  int ret = conv->configure(2, 2, kernel.size(), n_samples, n_samples, Convproc::MAXPART, density);
 
   if (ret != 0) {
     util::warning(std::format("{}can't initialise zita-convolver engine: {}", log_tag, ret));
