@@ -51,6 +51,7 @@
 #include "config.h"
 #include "db_manager.hpp"
 #include "global_shortcuts.hpp"
+#include "iostream"
 #include "kcolor_manager.hpp"
 #include "local_client.hpp"
 #include "local_server.hpp"
@@ -153,7 +154,7 @@ static void initGlobalBypass(StreamInputEffects& sie, StreamOutputEffects& soe)
     soe.set_bypass(DbMain::bypass());
     sie.set_bypass(DbMain::bypass());
 
-    util::info((DbMain::bypass() ? "Enabling global bypass" : "Disabling global bypass"));
+    util::debug((DbMain::bypass() ? "Enabling global bypass" : "Disabling global bypass"));
   };
 
   update_bypass_state();
@@ -163,7 +164,7 @@ static void initGlobalBypass(StreamInputEffects& sie, StreamOutputEffects& soe)
 
 static void initGlobalShortcuts(GlobalShortcuts* shortcuts) {
   auto bind = [shortcuts]() {
-    util::info("XDG Global Shortcuts experimental feature is enabled for this session.");
+    util::debug("XDG Global Shortcuts experimental feature is enabled for this session.");
 
     const auto session = qEnvironmentVariable("XDG_SESSION_DESKTOP");
     const auto desktop = qEnvironmentVariable("XDG_CURRENT_DESKTOP");
@@ -286,6 +287,22 @@ static int runSecondaryInstance(KAboutData& about, QApplication& app, CommandLin
     show_window = false;
   });
 
+  QObject::connect(&parser, &CommandLineParser::onGetLastLoadedPreset, [&](PipelineType type) {
+    auto preset = local_client->getLastLoadedPreset(type);
+    std::cout << preset.toStdString() << '\n';
+    show_window = false;
+  });
+
+  QObject::connect(&parser, &CommandLineParser::onGetLastLoadedInputOutputPreset, [&]() {
+    auto input_preset = local_client->getLastLoadedPreset(PipelineType::input);
+    auto output_preset = local_client->getLastLoadedPreset(PipelineType::output);
+
+    std::cout << "input: " << input_preset.toStdString() << '\n';
+    std::cout << "output: " << output_preset.toStdString() << '\n';
+
+    show_window = false;
+  });
+
   parser.set_is_primary(false);
   parser.process(about, &app);
   parser.process_events();
